@@ -13,7 +13,7 @@ def cookie_to_dict(cookies: str) -> dict:
     :param cookies: cookie字符串
     :return: dict
     """
-    return dict(x.split('=') for x in cookies.split('; '))  # noqa
+    return dict(x.split('=', 1) for x in cookies.split('; '))  # noqa
 
 
 def headers_to_dict(headers: str) -> dict:
@@ -40,3 +40,24 @@ def gen_unique_id():
     :return:
     """
     return f"{uuid4().hex}"
+
+
+def sizeof_fmt(num: int, suffix='B') -> str:
+    """
+    将字节转换为可读的格式
+    :param num: 字节长度
+    :param suffix: 后缀
+    :return: str
+
+    >>> sizeof_fmt(1024)
+    '1.0 KB'
+    """
+    for unit in ['', 'K', 'M', 'G', 'T', 'P', 'E', 'Z']:
+        if abs(num) < 1024.0:
+            return f"{num:.1f} {unit}{suffix}"
+        num /= 1024.0
+    return f"{num:.1f} Y{suffix}"
+
+
+if __name__ == '__main__':
+    print(sizeof_fmt(1024))
